/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * The HI  object is the global object used by ODE MMC's JavaScript
 * library.
 */
if (typeof HI == "undefined" || HI) {
    /**
     * The HI global namespace object. If HI is already defined, the
     * existing HI object will not be overwritten so that defined
     * namespaces are preserved
     */
    var HI = {};
}

/**
 * Returns the namespace specified and creates if it doesn't exist
 *
 * @method namespace
 * @static
 * @param {String*} arguments 1-n namespaces to create
 * @return {Object} A reference to the last namespace object created
 */

HI.namespace = function() {
    var args = arguments, o = null, i, j , d;
    for (i = 0; i < args.length; i = i + 1) {
        d = args[i].split(".");
        o = HI;

        // HI is implied, so it is ignored if it is included
        for (j = (d[0] == "HI") ? 1 : 0; j < d.length; j = j + 1) {
            o[d[j]] = o[d[j]] || {};
            o = o[d[j]];
        }
    }

    return o;
};

(function(){
    HI.namespace("Task", "deployment");
})();

HI.urlEncode= function(stringToEncode){
    function utf8Eencode(string) {
            string = string.replace(/\r\n/g,"\n");
            var utftext = "";

            for (var n = 0; n < string.length; n++) {

                var c = string.charCodeAt(n);

                if (c < 128) {
                    utftext += String.fromCharCode(c);
                }
                else if((c > 127) && (c < 2048)) {
                    utftext += String.fromCharCode((c >> 6) | 192);
                    utftext += String.fromCharCode((c & 63) | 128);
                }
                else {
                    utftext += String.fromCharCode((c >> 12) | 224);
                    utftext += String.fromCharCode(((c >> 6) & 63) | 128);
                    utftext += String.fromCharCode((c & 63) | 128);
                }

            }

            return utftext;
    }

    return escape(utf8Eencode(stringToEncode));

};
